@@ -21,6 +21,7 @@ import os
 import random
 import re
 import time
+from typing import List
 
 from google.cloud import ndb
 import six
@@ -61,6 +62,7 @@ from clusterfuzz._internal.system import environment
 from clusterfuzz._internal.system import process_handler
 from clusterfuzz._internal.system import shell
 from clusterfuzz.fuzz import engine
+from clusterfuzz.stacktraces.__init__ import CrashInfo
 
 SelectionMethod = namedtuple('SelectionMethod', 'method_name probability')
 
@@ -1003,14 +1005,16 @@ def create_testcase(group, context):
   return testcase
 
 
-def filter_crashes(crashes):
+def filter_crashes(crashes: List[CrashInfo]) -> List[CrashInfo]:
   """Filter crashes based on is_valid()."""
   filtered = []
 
   for crash in crashes:
     if not crash.is_valid():
-      logs.log('Ignore crash (reason=%s, type=%s, state=%s).' %
-               (crash.get_error(), crash.crash_type, crash.crash_state))
+      logs.log(
+          (f'Ignore crash (reason={crash.get_error()}, '
+           f'type={crash.crash_type}, state={crash.crash_state})'),
+          stacktrace=crash.crash_stacktrace)
       continue
 
     filtered.append(crash)
@@ -1217,10 +1221,11 @@ def get_strategy_distribution_from_ndb():
 
 def _get_issue_metadata_from_environment(variable_name):
   """Get issue metadata from environment."""
-  values = str(environment.get_value(variable_name, '')).split()
+  values = str(environment.get_value_string(variable_name, '')).split(',')
   # Allow a variation with a '_1' to specified. This is needed in cases where
   # this is specified in both the job and the bot environment.
-  values.extend(str(environment.get_value(variable_name + '_1', '')).split())
+  values.extend(
+      str(environment.get_value_string(variable_name + '_1', '')).split(','))
   return [value.strip() for value in values if value.strip()]
 
 
