@@ -13,7 +13,6 @@
 # limitations under the License.
 """Process handling utilities."""
 
-from distutils import spawn
 import os
 import subprocess
 import sys
@@ -171,7 +170,7 @@ class ChildProcess(object):
         else:
           stdout += line
 
-        sys.stdout.write(line.decode())
+        sys.stdout.write(utils.decode_to_unicode(line))
 
       self._popen.wait()
     else:
@@ -423,14 +422,15 @@ class UnshareProcessRunnerMixin(object):
     if environment.platform() != 'LINUX':
       raise RuntimeError('UnshareProcessRunner only supported on Linux')
 
-    unshare_path = spawn.find_executable('unshare')
+    unshare_path = environment.get_default_tool_path('unshare')
     if not unshare_path:
       raise RuntimeError('unshare not found')
 
-    command = [unshare_path]
-    command.extend([
+    command = [
+        unshare_path,
+        '-c',  # Map current user to same user in user namespace.
         '-n',  # Enter network namespace.
-    ])
+    ]
 
     command.append(self._executable_path)
     command.extend(self._default_args)
