@@ -354,9 +354,9 @@ class FuzzTest(fake_fs_unittest.TestCase):
         'dict_used': 1,
         'edge_coverage': 411,
         'edges_total': 398467,
-        'expected_duration': 3580,
+        'expected_duration': 3600,
         'feature_coverage': 1873,
-        'fuzzing_time_percent': 0.055865921787709494,
+        'fuzzing_time_percent': 0.05555555555555555,
         'initial_edge_coverage': 410,
         'initial_feature_coverage': 1869,
         'leak_count': 0,
@@ -440,12 +440,6 @@ def setup_testcase_and_corpus(testcase, corpus):
   return copied_testcase_path, copied_corpus_path
 
 
-def get_fuzz_timeout(fuzz_time):
-  """Return timeout for fuzzing."""
-  return (fuzz_time + libfuzzer.LibFuzzerCommon.LIBFUZZER_CLEAN_EXIT_TIME +
-          libfuzzer.LibFuzzerCommon.SIGTERM_WAIT_TIME)
-
-
 def mock_get_directory_file_count(dir_path):
   """Mocked version, always return 1 for new testcases directory."""
   if dir_path == os.path.join(fuzzer_utils.get_temp_dir(), 'new'):
@@ -544,8 +538,7 @@ class IntegrationTests(BaseIntegrationTest):
     dict_path = target_path + '.dict'
     options = engine_impl.prepare(corpus_path, target_path, DATA_DIR)
 
-    results = engine_impl.fuzz(target_path, options, TEMP_DIR,
-                               get_fuzz_timeout(5.0))
+    results = engine_impl.fuzz(target_path, options, TEMP_DIR, 5.0)
     self.assert_has_stats(results.stats)
     self.compare_arguments(
         os.path.join(DATA_DIR, 'test_fuzzer'), [
@@ -579,8 +572,7 @@ class IntegrationTests(BaseIntegrationTest):
     dict_path = target_path + '.dict'
     options = engine_impl.prepare(corpus_path, target_path, DATA_DIR)
 
-    results = engine_impl.fuzz(target_path, options, TEMP_DIR,
-                               get_fuzz_timeout(5))
+    results = engine_impl.fuzz(target_path, options, TEMP_DIR, 5)
     self.assert_has_stats(results.stats)
     self.compare_arguments(
         os.path.join(DATA_DIR, 'test_fuzzer_old'), [
@@ -610,8 +602,7 @@ class IntegrationTests(BaseIntegrationTest):
                                                  'always_crash_fuzzer')
     options = engine_impl.prepare(corpus_path, target_path, DATA_DIR)
 
-    results = engine_impl.fuzz(target_path, options, TEMP_DIR,
-                               get_fuzz_timeout(5))
+    results = engine_impl.fuzz(target_path, options, TEMP_DIR, 5)
 
     self.assert_has_stats(results.stats)
     self.compare_arguments(
@@ -651,8 +642,7 @@ class IntegrationTests(BaseIntegrationTest):
     target_path = engine_common.find_fuzzer_path(DATA_DIR, 'test_fuzzer')
     dict_path = target_path + '.dict'
     options = engine_impl.prepare(corpus_path, target_path, DATA_DIR)
-    results = engine_impl.fuzz(target_path, options, TEMP_DIR,
-                               get_fuzz_timeout(5))
+    results = engine_impl.fuzz(target_path, options, TEMP_DIR, 5)
 
     self.compare_arguments(
         os.path.join(DATA_DIR, 'test_fuzzer'), [
@@ -722,7 +712,7 @@ class IntegrationTests(BaseIntegrationTest):
     target_path = engine_common.find_fuzzer_path(DATA_DIR,
                                                  'analyze_dict_fuzzer')
     options = engine_impl.prepare(corpus_path, target_path, DATA_DIR)
-    engine_impl.fuzz(target_path, options, TEMP_DIR, get_fuzz_timeout(5))
+    engine_impl.fuzz(target_path, options, TEMP_DIR, 5)
     expected_recommended_dictionary = set([
         '"APPLE"',
         '"GINGER"',
@@ -759,8 +749,7 @@ class IntegrationTests(BaseIntegrationTest):
       target_path = engine_common.find_fuzzer_path(DATA_DIR, fuzz_target_name)
       engine_impl = engine.LibFuzzerEngine()
       options = engine_impl.prepare(corpus_path, target_path, DATA_DIR)
-      results = engine_impl.fuzz(target_path, options, TEMP_DIR,
-                                 get_fuzz_timeout(5))
+      results = engine_impl.fuzz(target_path, options, TEMP_DIR, 5)
     finally:
       shutil.rmtree(os.environ['MUTATOR_PLUGINS_DIR'])
 
@@ -817,7 +806,7 @@ class IntegrationTests(BaseIntegrationTest):
     engine_impl = engine.LibFuzzerEngine()
     options = engine_impl.prepare(corpus_path, target_path, DATA_DIR)
     options.arguments.append('-runs=10')
-    engine_impl.fuzz(target_path, options, TEMP_DIR, get_fuzz_timeout(5))
+    engine_impl.fuzz(target_path, options, TEMP_DIR, 5)
 
     # Verify that both the newly found minimal testcase and the nonminimal
     # testcase are in the corpus.
@@ -843,8 +832,7 @@ class IntegrationTests(BaseIntegrationTest):
     options = engine_impl.prepare(corpus_path, target_path, DATA_DIR)
     options.extra_env['EXIT_FUZZER_CODE'] = '1'
 
-    results = engine_impl.fuzz(target_path, options, TEMP_DIR,
-                               get_fuzz_timeout(5))
+    results = engine_impl.fuzz(target_path, options, TEMP_DIR, 5)
     self.assertEqual(1, self.mock.log_error.call_count)
 
     self.assertEqual(1, len(results.crashes))
@@ -870,8 +858,7 @@ class IntegrationTests(BaseIntegrationTest):
     options = engine_impl.prepare(corpus_path, target_path, DATA_DIR)
     options.extra_env['EXIT_FUZZER_CODE'] = exit_code
 
-    results = engine_impl.fuzz(target_path, options, TEMP_DIR,
-                               get_fuzz_timeout(5))
+    results = engine_impl.fuzz(target_path, options, TEMP_DIR, 5)
 
     self.assertEqual(1, len(results.crashes))
     self.assertEqual(TEMP_DIR, os.path.dirname(results.crashes[0].input_path))
@@ -897,10 +884,9 @@ class IntegrationTests(BaseIntegrationTest):
     invalid_dict_path = os.path.join(DATA_DIR, 'invalid.dict')
     options.arguments.append('-dict=' + invalid_dict_path)
 
-    engine_impl.fuzz(target_path, options, TEMP_DIR, get_fuzz_timeout(5))
+    engine_impl.fuzz(target_path, options, TEMP_DIR, 5)
 
 
-@unittest.skip('needs root')
 @test_utils.integration
 class UnshareIntegrationTests(IntegrationTests):
   """Unshare runner integration tests."""
@@ -912,8 +898,11 @@ class UnshareIntegrationTests(IntegrationTests):
   def compare_arguments(self, target_path, arguments, corpora_or_testcase,
                         actual):
     """Compare expected arguments."""
-    self.assertListEqual(actual, ['/usr/bin/unshare', '-n', target_path] +
-                         arguments + corpora_or_testcase)
+    self.assertListEqual(actual, [
+        os.path.join(
+            environment.get_value('ROOT_DIR'), 'resources', 'platform', 'linux',
+            'unshare'), '-c', '-n', target_path
+    ] + arguments + corpora_or_testcase)
 
 
 @test_utils.integration
@@ -968,8 +957,7 @@ class MinijailIntegrationTests(IntegrationTests):
     options = engine_impl.prepare(corpus_path, target_path, DATA_DIR)
     options.extra_env['EXIT_FUZZER_CODE'] = exit_code
 
-    results = engine_impl.fuzz(target_path, options, TEMP_DIR,
-                               get_fuzz_timeout(5))
+    results = engine_impl.fuzz(target_path, options, TEMP_DIR, 5)
 
     self.assertEqual(1, len(results.crashes))
     self.assertEqual(TEMP_DIR, os.path.dirname(results.crashes[0].input_path))
@@ -1025,7 +1013,7 @@ class IntegrationTestsFuchsia(BaseIntegrationTest):
     options = engine_impl.prepare(corpus_path, 'example-fuzzers/crash_fuzzer',
                                   DATA_DIR)
     results = engine_impl.fuzz('example-fuzzers/crash_fuzzer', options,
-                               TEMP_DIR, get_fuzz_timeout(20))
+                               TEMP_DIR, 20)
 
     # If we don't get a crash, something went wrong.
     self.assertIn('Test unit written to', results.logs)
@@ -1183,8 +1171,7 @@ class IntegrationTestsAndroid(BaseIntegrationTest, android_helpers.AndroidTest):
     dict_path = target_path + '.dict'
     options = engine_impl.prepare(corpus_path, target_path, ANDROID_DATA_DIR)
 
-    results = engine_impl.fuzz(target_path, options, TEMP_DIR,
-                               get_fuzz_timeout(5))
+    results = engine_impl.fuzz(target_path, options, TEMP_DIR, 5)
 
     self.assert_has_stats(results.stats)
     self.assertEqual([
@@ -1221,8 +1208,7 @@ class IntegrationTestsAndroid(BaseIntegrationTest, android_helpers.AndroidTest):
                                                  'always_crash_fuzzer')
     options = engine_impl.prepare(corpus_path, target_path, ANDROID_DATA_DIR)
 
-    results = engine_impl.fuzz(target_path, options, TEMP_DIR,
-                               get_fuzz_timeout(5))
+    results = engine_impl.fuzz(target_path, options, TEMP_DIR, 5)
 
     self.assert_has_stats(results.stats)
     self.assertEqual([
@@ -1270,8 +1256,7 @@ class IntegrationTestsAndroid(BaseIntegrationTest, android_helpers.AndroidTest):
                                                  'test_fuzzer')
     dict_path = target_path + '.dict'
     options = engine_impl.prepare(corpus_path, target_path, ANDROID_DATA_DIR)
-    results = engine_impl.fuzz(target_path, options, TEMP_DIR,
-                               get_fuzz_timeout(5))
+    results = engine_impl.fuzz(target_path, options, TEMP_DIR, 5)
 
     self.assertEqual([
         self.adb_path,
@@ -1348,7 +1333,7 @@ class IntegrationTestsAndroid(BaseIntegrationTest, android_helpers.AndroidTest):
                                                  'analyze_dict_fuzzer')
     options = engine_impl.prepare(corpus_path, target_path, DATA_DIR)
 
-    engine_impl.fuzz(target_path, options, TEMP_DIR, get_fuzz_timeout(5.0))
+    engine_impl.fuzz(target_path, options, TEMP_DIR, 5.0)
     expected_recommended_dictionary = set([
         '"APPLE"',
         '"GINGER"',
